Modules
- __buffa
- compiler
- descriptor_
proto - enum_
descriptor_ proto - extension_
range_ options - feature_
set - feature_
set_ defaults - field_
descriptor_ proto - field_
options - file_
options - generated_
code_ info - method_
options - source_
code_ info - uninterpreted_
option
Structs
- Descriptor
Proto - Describes a message type.
- Enum
Descriptor Proto - Describes an enum type.
- Enum
Options - Enum
Value Descriptor Proto - Describes a value within an enum.
- Enum
Value Options - Extension
Range Options - Feature
Set - =================================================================== Features
- Feature
SetDefaults - A compiled specification for the defaults of a set of features. These messages are generated from FeatureSet extensions and can be used to seed feature resolution. The resolution with this object becomes a simple search for the closest matching edition, followed by proto merges.
- Field
Descriptor Proto - Describes a field within a message.
- Field
Options - File
Descriptor Proto - Describes a complete .proto file.
- File
Descriptor Set - The protocol compiler can output a FileDescriptorSet containing the .proto files it parses.
- File
Options - =================================================================== Options
- Generated
Code Info - Describes the relationship between generated code and its original source file. A GeneratedCodeInfo message is associated with only one generated source file, but may contain references to different source .proto files.
- Message
Options - Method
Descriptor Proto - Describes a method of a service.
- Method
Options - Oneof
Descriptor Proto - Describes a oneof.
- Oneof
Options - Service
Descriptor Proto - Describes a service.
- Service
Options - Source
Code Info - =================================================================== Optional source code info
- Uninterpreted
Option - A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.
Enums
- Edition
- The full set of known editions.
- Symbol
Visibility - Describes the ‘visibility’ of a symbol with respect to the proto import
system. Symbols can only be imported when the visibility rules do not prevent
it (ex: local symbols cannot be imported). Visibility modifiers can only set
on
messageandenumas they are the only types available to be referenced from other files.