pub struct EnumReservedRange {
pub start: Option<i32>,
pub end: Option<i32>,
/* private fields */
}Expand description
Range of reserved numeric values. Reserved values may not be used by entries in the same enum. Reserved ranges may not overlap.
Note that this is distinct from DescriptorProto.ReservedRange in that it is inclusive such that it can appropriately represent the entire int32 domain.
Fields
start: Option<i32>Inclusive.
Field 1: start
end: Option<i32>Inclusive.
Field 2: end
Implementations
Sourceimpl EnumReservedRange
impl EnumReservedRange
Sourcepub fn with_start(self, value: i32) -> EnumReservedRange
pub fn with_start(self, value: i32) -> EnumReservedRange
Sets Self::start to Some(value), consuming and returning self.
Sourcepub fn with_end(self, value: i32) -> EnumReservedRange
pub fn with_end(self, value: i32) -> EnumReservedRange
Sets Self::end to Some(value), consuming and returning self.