#[non_exhaustive]pub enum EncodableImpls {
Outputs,
AllMessages,
}Expand description
Which messages get generated ::connectrpc::Encodable view impl
pairs. See Options::encodable_impls.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Outputs
Emit the impl pair only for the RPC output types of the targeted protos’ services (the default).
AllMessages
Emit the impl pair for every message defined in each targeted proto, including protos that declare no services.