Module descriptor

Module descriptor 

Modules

descriptor_proto
enum_descriptor_proto
extension_range_options
feature_set
feature_set_defaults
field_descriptor_proto
field_options
file_options
generated_code_info
method_options
source_code_info
uninterpreted_option

Structs

DescriptorProto
Describes a message type.
EnumDescriptorProto
Describes an enum type.
EnumOptions
EnumValueDescriptorProto
Describes a value within an enum.
EnumValueOptions
ExtensionRangeOptions
FeatureSet
=================================================================== Features
FeatureSetDefaults
A compiled specification for the defaults of a set of features. These messages are generated from FeatureSet extensions and can be used to seed feature resolution. The resolution with this object becomes a simple search for the closest matching edition, followed by proto merges.
FieldDescriptorProto
Describes a field within a message.
FieldOptions
FileDescriptorProto
Describes a complete .proto file.
FileDescriptorSet
The protocol compiler can output a FileDescriptorSet containing the .proto files it parses.
FileOptions
=================================================================== Options
GeneratedCodeInfo
Describes the relationship between generated code and its original source file. A GeneratedCodeInfo message is associated with only one generated source file, but may contain references to different source .proto files.
MessageOptions
MethodDescriptorProto
Describes a method of a service.
MethodOptions
OneofDescriptorProto
Describes a oneof.
OneofOptions
ServiceDescriptorProto
Describes a service.
ServiceOptions
SourceCodeInfo
=================================================================== Optional source code info
UninterpretedOption
A message representing a option the parser does not recognize. This only appears in options protos created by the compiler::Parser class. DescriptorPool resolves these when building Descriptor objects. Therefore, options protos in descriptor objects (e.g. returned by Descriptor::options(), or produced by Descriptor::CopyTo()) will never have UninterpretedOptions in them.

Enums

Edition
The full set of known editions.
SymbolVisibility
Describes the ‘visibility’ of a symbol with respect to the proto import system. Symbols can only be imported when the visibility rules do not prevent it (ex: local symbols cannot be imported). Visibility modifiers can only set on message and enum as they are the only types available to be referenced from other files.